@@ -25,6 +25,7 @@ sub run {
     $p->getoptions(
         "h|help"     => \$self->{help},
         "c|config=s" => \$self->{config},
+        "s|set=s%"   => \$self->{override_settings},
     );
     return $self->usage if $self->{help};
 
@@ -34,14 +35,14 @@ sub run {
         return $self->usage;
     }
 
-
-    my ($role, $task) = @ARGV;
+    my $role = shift @ARGV;
+    my $task = shift @ARGV;
     unless ($role && $task) {
         $self->print("please specify role and task\n");
         return $self->usage;
     }
 
-    $self->cinnamon->run($role, $task, config => $self->{config});
+    $self->cinnamon->run($role, $task, config => $self->{config}, override_settings => $self->{override_settings});
 }
 
 sub usage {
